Tx

Struct Tx 

pub struct Tx { /* private fields */ }
A database transaction.

Wraps a pooled connection with an active transaction. If commit() is not called before the Tx is dropped, the transaction is automatically rolled back when the connection returns to the pool.

Implementations

Source

impl Tx

pub async fn commit(self) -> Result<(), FlozError>

Commit the transaction.

pub async fn rollback(self) -> Result<(), FlozError>

Explicitly rollback the transaction.