Re-exports
pub use sqlx;
Modules
- migration
- prelude
- Convenience re-exports for common floz usage.
- types
- ORM type aliases — semantic DB types that map to SQL.
Structs
- AnyColumn
- A type-erased column reference for use in dynamic contexts (e.g.,
Valuebindings,user_row!). - Column
- A typed reference to a database column.
- Db
- A database connection pool that auto-selects the backend based on the connection URL scheme.
- Delete
Query - A DELETE query builder.
- Insert
Many Query - A bulk INSERT query builder.
- Insert
Query - A single-row INSERT query builder.
- Order
Expr - An ordering expression for ORDER BY clauses.
- Paginate
Query - Builder for paginated queries.
- Paginated
- The result of a paginated query.
- Select
Query - A SELECT query builder.
- Tx
- A database transaction.
- Update
Query - An UPDATE query builder.
Enums
- Expr
- A composable SQL expression node.
- Floz
Error - All errors that can be returned by floz operations.
- Order
Direction - The direction of an ORDER BY clause.
- Value
- Represents a SQL parameter value with full type information.
Traits
- Executor
- The core database execution trait.
- Floz
Hooks - Lifecycle hooks for database operations.
- Floz
RowBound